@@ -24,22 +24,38 @@
 
 #include "pulseaudio.h"
 #include "client.h"
+#include "sink.h"
+#include "source.h"
+#include "context.h"
 
 #include "globalactioncollection.h"
 #include "volumeosd.h"
 
+static QJSValue pulseaudio_singleton(QQmlEngine *engine, QJSEngine *scriptEngine)
+{
+    Q_UNUSED(engine)
+
+    QJSValue object = scriptEngine->newObject();
+    object.setProperty(QStringLiteral("NormalVolume"), (double) QPulseAudio::Context::NormalVolume);
+    object.setProperty(QStringLiteral("MinimalVolume"), (double) QPulseAudio::Context::MinimalVolume);
+    object.setProperty(QStringLiteral("MaximalVolume"), (double) QPulseAudio::Context::MaximalVolume);
+    return object;
+}
+
 void Plugin::registerTypes(const char* uri)
 {
-    qmlRegisterType<QPulseAudio::Context>();
     qmlRegisterType<QPulseAudio::CardModel>(uri, 0, 1, "CardModel");
-    qmlRegisterType<QPulseAudio::ClientModel>(uri, 0, 1, "ClientModel");
     qmlRegisterType<QPulseAudio::SinkModel>(uri, 0, 1, "SinkModel");
     qmlRegisterType<QPulseAudio::SinkInputModel>(uri, 0, 1, "SinkInputModel");
-    qmlRegisterType<QPulseAudio::ReverseFilterModel>(uri, 0, 1, "ReverseFilterModel");
     qmlRegisterType<QPulseAudio::SourceModel>(uri, 0, 1, "SourceModel");
     qmlRegisterType<QPulseAudio::SourceOutputModel>(uri, 0, 1, "SourceOutputModel");
+    qmlRegisterType<QPulseAudio::StreamRestoreModel>(uri, 0, 1, "StreamRestoreModel");
     qmlRegisterType<GlobalAction>(uri, 0, 1, "GlobalAction");
     qmlRegisterType<GlobalActionCollection>(uri, 0, 1, "GlobalActionCollection");
     qmlRegisterType<VolumeOSD>(uri, 0, 1, "VolumeOSD");
+    qmlRegisterSingletonType(uri, 0, 1, "PulseAudio", pulseaudio_singleton);
+
     qmlRegisterType<QPulseAudio::Client>();
+    qmlRegisterType<QPulseAudio::Sink>();
+    qmlRegisterType<QPulseAudio::Source>();
 }
