@@ -25,6 +25,8 @@ namespace QPulseAudio
 
 Stream::Stream(QObject *parent)
     : VolumeObject(parent)
+    , m_clientIndex(PA_INVALID_INDEX)
+    , m_virtualStream(false)
 {
     m_volumeWritable = false;
     m_hasVolume = false;
@@ -44,4 +46,14 @@ Client *Stream::client() const
     return context()->clients().data().value(m_clientIndex, nullptr);
 }
 
+bool Stream::isVirtualStream() const
+{
+    return m_virtualStream;
+}
+
+quint32 Stream::deviceIndex() const
+{
+    return m_deviceIndex;
+}
+
 } // QPulseAudio
